@@ -54,6 +54,7 @@ from .manifest import (
     HelmRepository,
     Kustomization,
     Manifest,
+    SECRET_KIND,
 )
 
 __all__ = [
@@ -173,6 +174,9 @@ class MetadataSelector:
     skip_crds: bool = True
     """If false, CRDs may be processed, depending on the resource type."""
 
+    skip_secrets: bool = True
+    """If false, Secrets may be processed, depending on the resource type."""
+
     visitor: ResourceVisitor | None = None
     """Visitor for the specified object type that can be used for building."""
 
@@ -338,19 +342,19 @@ def make_clusters(kustomizations: list[Kustomization]) -> list[Cluster]:
     _LOGGER.debug("roots=%s", roots)
     for root in roots:
         root_ks = graph.nodes[root]["ks"]
-        child_nodes = list(networkx.descendants(graph, root))
-        child_nodes.sort()
-        children = [graph.nodes[child]["ks"] for child in child_nodes]
+        nodes = [root] + list(networkx.descendants(graph, root))
+        nodes.sort()
+        kustomizations = [graph.nodes[node]["ks"] for node in nodes]
         clusters.append(
             Cluster(
                 name=root_ks.name,
                 namespace=root_ks.namespace,
                 path=root_ks.path,
-                kustomizations=children,
+                kustomizations=kustomizations,
             )
         )
         _LOGGER.debug(
-            "Created cluster %s with %s kustomizations", root_ks.name, len(children)
+            "Created cluster %s with %s kustomizations", root_ks.name, len(nodes)
         )
 
     return clusters
@@ -396,8 +400,12 @@ async def build_kustomization(
         return ([], [])
 
     cmd = kustomize.build(root / kustomization.path)
+    skips = []
     if kustomization_selector.skip_crds:
-        cmd = cmd.grep(f"kind=^{CRD_KIND}$", invert=True)
+        skips.append(CRD_KIND)
+    if kustomization_selector.skip_secrets:
+        skips.append(SECRET_KIND)
+    cmd = cmd.skip_resources(skips)
     cmd = await cmd.stash(
         Path(
             "-".join(
