@@ -3,11 +3,13 @@
 import asyncio
 from argparse import ArgumentParser
 from argparse import _SubParsersAction as SubParsersAction
+from dataclasses import asdict
 import difflib
 import logging
 import pathlib
 import tempfile
-from typing import cast, Generator
+from typing import cast, Generator, Any
+import yaml
 
 
 import git
@@ -32,21 +34,81 @@ def changed_files(repo: git.repo.Repo) -> set[str]:
 
 
 def perform_diff(
-    a: ResourceContentOutput, b: ResourceContentOutput
+    a: ResourceContentOutput,
+    b: ResourceContentOutput,
+    n: int,
 ) -> Generator[str, None, None]:
     """Generate diffs between the two output objects."""
     for key in set(a.content.keys()) | set(b.content.keys()):
-        _LOGGER.debug("Diffing results for %s", key)
+        _LOGGER.debug("Diffing results for %s (n=%d)", key, n)
         diff_text = difflib.unified_diff(
-            a=a.content.get(key) or [],
-            b=b.content.get(key) or [],
-            fromfile=key,
-            tofile=key,
+            a=a.content.get(key, []),
+            b=b.content.get(key, []),
+            fromfile=key.label,
+            tofile=key.label,
+            n=n,
         )
         for line in diff_text:
             yield line
 
 
+def perform_yaml_diff(
+    a: ResourceContentOutput,
+    b: ResourceContentOutput,
+    n: int,
+) -> Generator[str, None, None]:
+    """Generate diffs between the two output objects."""
+
+    def str_presenter(dumper: yaml.Dumper, data: Any) -> Any:
+        """Represent multi-line yaml strings as you'd expect.
+
+        See https://github.com/yaml/pyyaml/issues/240
+        """
+        return dumper.represent_scalar(
+            "tag:yaml.org,2002:str", data, style="|" if data.count("\n") > 0 else None
+        )
+
+    yaml.add_representer(str, str_presenter)
+
+    diffs = []
+    for key in set(a.content.keys()) | set(b.content.keys()):
+        _LOGGER.debug("Diffing results for %s (n=%d)", key, n)
+        diff_text = difflib.unified_diff(
+            a=a.content.get(key, []),
+            b=b.content.get(key, []),
+            fromfile=key.label,
+            tofile=key.label,
+            n=n,
+        )
+        diff_content = "\n".join(diff_text)
+        if not diff_content:
+            continue
+        obj = {
+            **asdict(key),
+            "diff_text": diff_content,
+        }
+        diffs.append(obj)
+    yield yaml.dump(diffs, sort_keys=False, explicit_start=True, default_style=None)
+
+
+def add_diff_flags(args: ArgumentParser) -> None:
+    """Add shared diff flags."""
+    args.add_argument(
+        "--output",
+        "-o",
+        choices=["diff", "yaml"],
+        default="diff",
+        help="Output format of the command",
+    )
+    args.add_argument(
+        "--unified",
+        "-u",
+        type=int,
+        default=3,
+        help="output NUM (default 3) lines of unified context",
+    )
+
+
 class DiffKustomizationAction:
     """Flux-local diff for Kustomizations."""
 
@@ -68,11 +130,14 @@ class DiffKustomizationAction:
             ),
         )
         selector.add_ks_selector_flags(args)
+        add_diff_flags(args)
         args.set_defaults(cls=cls)
         return args
 
     async def run(  # type: ignore[no-untyped-def]
         self,
+        output: str,
+        unified: int,
         **kwargs,  # pylint: disable=unused-argument
     ) -> None:
         """Async Action implementation."""
@@ -95,7 +160,11 @@ class DiffKustomizationAction:
             return
 
         _LOGGER.debug("Diffing content")
-        for line in perform_diff(orig_content, content):
+        if output == "yaml":
+            result = perform_yaml_diff(orig_content, content, unified)
+        else:
+            result = perform_diff(orig_content, content, unified)
+        for line in result:
             print(line)
 
 
@@ -120,19 +189,14 @@ class DiffHelmReleaseAction:
             ),
         )
         selector.add_hr_selector_flags(args)
-        args.add_argument(
-            "--output",
-            "-o",
-            choices=["diff", "yaml"],
-            default="diff",
-            help="Output format of the command",
-        )
+        add_diff_flags(args)
         args.set_defaults(cls=cls)
         return args
 
     async def run(  # type: ignore[no-untyped-def]
         self,
         output: str,
+        unified: int,
         **kwargs,  # pylint: disable=unused-argument
     ) -> None:
         """Async Action implementation."""
@@ -162,15 +226,17 @@ class DiffHelmReleaseAction:
                     pathlib.Path(helm_cache_dir),
                     content.visitor(),
                     query.helm_release.skip_crds,
+                    skip_secrets=query.helm_release.skip_secrets,
                 ),
                 orig_helm_visitor.inflate(
                     pathlib.Path(helm_cache_dir),
                     orig_content.visitor(),
                     query.helm_release.skip_crds,
+                    skip_secrets=query.helm_release.skip_secrets,
                 ),
             )
 
-        for line in perform_diff(orig_content, content):
+        for line in perform_diff(orig_content, content, unified):
             print(line)
 
 
